const fs = require("fs");
const path = require("path");
const inquirer = require("inquirer");
const { showErrorText, showSuccessText } = require("../utils/index.js");

// 配置文件存放的地址（process.cwd()：当前命令行运行时的工作目录）
const deployConfigPath = `${path.join(process.cwd())}/deploy.config.js`;

// 获取用户输入的信息
const getUserInputInfo = function () {
  const prompt = [
    {
      type: "input",
      name: "script",
      message: "请输入打包命令",
    },
    {
      type: "input",
      name: "host",
      message: "请输入服务器地址",
    },
    {
      type: "number",
      name: "port",
      message: "请输入服务器端口号",
    },
    {
      type: "input",
      name: "username",
      message: "请输入服务器用户名",
    },
    {
      type: "input",
      name: "password",
      message: "请输入服务器密码",
    },
    {
      type: "input",
      name: "localPath",
      message: "请输入本地打包目录",
    },
    {
      type: "input",
      name: "remotePath",
      message: "请输入服务器部署路径",
    },
    {
      type: "confirm",
      name: "needEmail",
      message: "是否需要增加发邮件功能",
    },
    {
      type: "input",
      name: "addressee",
      message: "请输入收件人",
    },
    {
      type: "input",
      name: "title",
      message: "请输入邮件标题",
    },
    {
      type: "input",
      name: "content",
      message: "请输入邮件内容",
    },
  ];
  return inquirer.prompt(prompt);
};

// 创建配置文件
const createConfigFile = function (fileJson) {
  const str = `module.exports = ${JSON.stringify({ win: fileJson }, null, 2)}`;
  fs.writeFileSync(deployConfigPath, str);
};

module.exports = {
  description: "初始化命令",
  run: function () {
    if (fs.existsSync(deployConfigPath)) {
      showErrorText("deploy.config.js已存在，请勿重复初始化~");
      process.exit(1);
    } else {
      getUserInputInfo()
        .then((configInfo) => {
          createConfigFile(configInfo);
          showSuccessText("配置成功，请检查配置文件是否正确~");
          process.exit(0);
        })
        .catch((e) => {
          showErrorText("配置失败：" + e);
          process.exit(1);
        });
    }
  },
};
